@@ -74,7 +74,7 @@ sub init {
 	my $app = shift ;
 	$application = $app;
 	
-	my $pixdir = File::Spec->catdir(bum_Config->DATADIR, 'pixmaps/bum');
+	my $pixdir = File::Spec->catdir(bum_Config->DATADIR, 'pixmaps');
 	$pxbf_boh = Gtk2::Gdk::Pixbuf->new_from_file
 				($pixdir.'/bum_serv_boh.png');
 	$pxbf_on=Gtk2::Gdk::Pixbuf->new_from_file
@@ -472,7 +472,7 @@ sub set_info_text
 	my ($pkg,$info) = bumlib::new_get_script_info($key);
 
 	$buffer->delete($buffer->get_start_iter,$buffer->get_end_iter);
-  	$buffer->insert($buffer->get_start_iter,$pkg);
+  	$buffer->insert($buffer->get_start_iter,$key.": ".$pkg."\n");
 	$buffer->apply_tag_by_name ('title', $buffer->get_start_iter, $buffer->get_end_iter);
   	$buffer->insert($buffer->get_end_iter,$info);
 	
@@ -702,6 +702,8 @@ sub bum_save
 
 }
 
+
+
 sub change_priority {
 	
 	my ($priority_dlg, $service_label, $serv_name, $start_pri, $stop_pri, $start_spin,$stop_spin);
@@ -749,14 +751,11 @@ sub change_priority {
 sub check_if_lock
 {
 
-	my ($ret, $lockfile) = bumlib::make_lock();
-	if ($ret == 0) {
-		message(_("Another bum is running, or  the file:").
-				" <i>$lockfile</i> ".
-				_("remains locked!"),'GTK_MESSAGE_ERROR');
-		return FALSE;
+	my  $ret = bumlib::check_lock();
+	if ($ret) {
+		message(_("An instance of BUM is already running!"),'GTK_MESSAGE_ERROR');
 		}
-	return TRUE;		
+	return $ret;		
 }
 
 
